// -*- Mode: C++; -*-
/*
  declaration of the mixer - related classes
  this are the only which work direct with the device

  $Log: mixer.h,v $
  Revision 1.2  1999/07/05 05:41:12  ral
  Mixer-Fd ist keine statische globale Variable mehr, sondern objekt-bezogen.

  Revision 1.1  1999/07/05 04:37:34  ral
  Einige Aenderungen, CVS umgemodelt

  Revision 1.3  1997/10/24 13:38:52  ral
  design of mixer_dev changed

  Revision 1.2  1997/10/22 11:44:32  ral
  typedef of mixer info struct
  depends on the used version of sounddriver

  Revision 1.1  1997/10/20 11:27:52  ral
  Initial revision

  */
#include <sys/soundcard.h>
#include <stdlib.h>
#include <unistd.h>

#ifndef __mixer_h
#define __mixer_h

// this is required 'cause the
// mixerinfo structure is in the new OSS driver
// some larger than in the USS
#ifdef UNIX_SOUND_SYSTEM
struct info_mixer {
    char id[16];
    char name[32];
    int counter;
    int fillers[10];
};
typedef info_mixer minfo;
//typedef struct minfo info_t;
#else
typedef mixer_info minfo;
#endif

//forward declaration
class mixer_dev;

class mixer {
    friend class mixer_dev;

protected:
    int mixer_fd;
    int devmask;
    int recmask;
    int recsrc;
    int stereodev;
    static const char*names[SOUND_MIXER_NRDEVICES];
    int exclusiv_record;
    char DevName[51];

public:
    mixer();
    virtual ~mixer();
    int get_mixer_fd(){return mixer_fd;}
    int open_mixer(const char*devname=NULL);
    void close_mixer(){if (mixer_fd) close(mixer_fd); mixer_fd = 0;}
    int get_devmask(){return  devmask;}
    int get_recmask(){return recmask;}
    int get_recsrc(){return recsrc;}
    int get_stereodev(){return stereodev;}
    int is_valid_dev(int dev);
    int is_exclusiv(){return exclusiv_record;}
    void set_recmask();
    const char*get_name(){return DevName;}
};

class mixer_dev {

private:
    int devnumber;
    int balance;
    int value;
    const char*Name;
    mixer*use_mixer;

public:
    virtual ~mixer_dev(){};
    void set_balance(int nBalance);
    int get_balance(){return balance;}
    void set_value(int nValue);
    int get_value(){return value;}
    void read_values();
    mixer_dev(int nDev,mixer*use_mix);
    const char*get_name(){return Name;}
    int is_stereo();
    int is_recordsrc();
    void set_record(int On);
    int get_record();
};

#endif
